@@ -1,10 +1,10 @@
-import pandas as pd
-
 from typing import Iterable, Mapping
-from nbformat import ValidationError
 
-from .types import Interval, TimeInterval
+import pandas as pd
+from pydantic import ValidationError
+
 from .base import BaseIndex
+from .types import Interval, TimeInterval
 
 
 class IntervalIndex(BaseIndex):
@@ -17,8 +17,6 @@ class IntervalIndex(BaseIndex):
             raise ValidationError(
                 f"{name} field is a interval index but is not of type {type(Interval)}"
             )
-        # if not self.field.sub_fields:
-        #     raise ValidationError(f'You must specify a label type for the {name} index')
 
     def __init__(self, closed="right", **kwargs):
         super().__init__(**kwargs)
